@@ -132,7 +132,7 @@ plugins += [HTML2ZIP, PML2PMLZ, TXT2TXTZ, ArchiveExtract,]
 class ComicMetadataReader(MetadataReaderPlugin):
 
     name = 'Read comic metadata'
-    file_types = set(['cbr', 'cbz'])
+    file_types = set(['cbz'])
     description = _('Extract cover from comic files')
 
     def customization_help(self, gui=False):
@@ -143,19 +143,14 @@ class ComicMetadataReader(MetadataReaderPlugin):
             pos = stream.tell()
             id_ = stream.read(3)
             stream.seek(pos)
-            if id_ == b'Rar':
-                ftype = 'cbr'
-            elif id_.startswith(b'PK'):
+            if id_.startswith(b'PK'):
                 ftype = 'cbz'
-        if ftype == 'cbr':
-            from calibre.utils.unrar import extract_cover_image
-        else:
             from calibre.libunzip import extract_cover_image
         from calibre.ebooks.metadata import MetaInformation
         ret = extract_cover_image(stream)
         mi = MetaInformation(None, None)
         stream.seek(0)
-        if ftype in {'cbr', 'cbz'}:
+        if ftype in {'cbz'}:
             series_index = self.site_customization
             if series_index not in {'volume', 'issue'}:
                 series_index = 'volume'
@@ -354,17 +349,6 @@ class PMLMetadataReader(MetadataReaderPlugin):
         return get_metadata(stream)
 
 
-class RARMetadataReader(MetadataReaderPlugin):
-
-    name = 'Read RAR metadata'
-    file_types = set(['rar'])
-    description = _('Read metadata from ebooks in RAR archives')
-
-    def get_metadata(self, stream, ftype):
-        from calibre.ebooks.metadata.rar import get_metadata
-        return get_metadata(stream)
-
-
 class RBMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read RB metadata'
