@@ -526,7 +526,7 @@ def available_input_formats():
         if not is_disabled(plugin):
             for format in plugin.file_types:
                 formats.add(format)
-    formats.add('zip'), formats.add('rar')
+    formats.add('zip')
     return formats
 
 
@@ -624,7 +624,10 @@ def patch_metadata_plugins(possibly_updated_plugins):
             pup = possibly_updated_plugins.get(plugin.name)
             if pup is not None:
                 if pup.version > plugin.version and pup.minimum_calibre_version <= numeric_version:
-                    patches[i] = pup
+                    patches[i] = pup(None)
+                    # Metadata source plugins dont use initialize() but that
+                    # might change in the future, so be safe.
+                    patches[i].initialize()
     for i, pup in patches.iteritems():
         _initialized_plugins[i] = pup
 # }}}
