@@ -39,8 +39,8 @@ def get_filters():
             (_('Text books'), ['txt', 'text', 'rtf']),
             (_('PDF Books'), ['pdf', 'azw4']),
             (_('SNB Books'), ['snb']),
-            (_('Comics'), ['cbz', 'cbr', 'cbc']),
-            (_('Archives'), ['zip', 'rar']),
+            (_('Comics'), ['cbz', 'cbc']),
+            (_('Archives'), ['zip']),
             (_('Wordprocessor files'), ['odt', 'doc', 'docx']),
     ]
 
@@ -67,13 +67,13 @@ class AddAction(InterfaceAction):
             'sub-directories (Multiple books per directory, assumes every '
             'ebook file is a different book)')).triggered.connect(
                     self.add_recursive_multiple)
-        arm = self.add_archive_menu = self.add_menu.addMenu(_('Add multiple books from archive (ZIP/RAR)'))
+        arm = self.add_archive_menu = self.add_menu.addMenu(_('Add multiple books from archive (ZIP)'))
         self.create_menu_action(arm, 'recursive-single-archive', _(
             'One book per directory in the archive')).triggered.connect(partial(self.add_archive, True))
         self.create_menu_action(arm, 'recursive-multiple-archive', _(
             'Multiple books per directory in the archive')).triggered.connect(partial(self.add_archive, False))
         self.add_menu.addSeparator()
-        ma('add-empty', _('Add Empty book (Book entry with no formats)'),
+        ma('add-empty', _('Add empty book (Book entry with no formats)'),
                 shortcut='Shift+Ctrl+E').triggered.connect(self.add_empty)
         ma('add-isbn', _('Add from ISBN')).triggered.connect(self.add_from_isbn)
         self.add_menu.addSeparator()
@@ -200,7 +200,7 @@ class AddAction(InterfaceAction):
     def add_archive(self, single):
         paths = choose_files(
             self.gui, 'recursive-archive-add', _('Choose archive file'),
-            filters=[(_('Archives'), ('zip', 'rar'))], all_files=False, select_only_single_file=False)
+            filters=[(_('Archives'), ('zip'))], all_files=False, select_only_single_file=False)
         if paths:
             self.do_add_recursive(paths, single, list_of_archives=True)
 
