@@ -28,7 +28,7 @@ BASE_HREFS = {
         1 : '/opds',
 }
 
-STANZA_FORMATS = frozenset(['epub', 'pdb', 'pdf', 'cbr', 'cbz', 'djvu'])
+STANZA_FORMATS = frozenset(['epub', 'pdb', 'pdf', 'cbz', 'djvu'])
 
 
 def url_for(name, version, **kwargs):
