@@ -14,7 +14,7 @@ from contextlib import nested, closing
 
 
 from calibre import (browser, __appname__, iswindows, force_unicode,
-                    strftime, preferred_encoding, as_unicode)
+                    strftime, preferred_encoding, as_unicode, random_user_agent)
 from calibre.ebooks.BeautifulSoup import BeautifulSoup, NavigableString, CData, Tag
 from calibre.ebooks.metadata.opf2 import OPFCreator
 from calibre import entity_to_unicode
@@ -389,6 +389,10 @@ class BasicNewsRecipe(Recipe):
     #: with the URL scheme of your particular website.
     resolve_internal_links = False
 
+    #: Set to True if you want to use gziped transfers. Note that some old servers flake out with this
+    #: so it is off by default.
+    handle_gzip = False
+
     # See the built-in recipes for examples of these settings.
 
     def short_title(self):
@@ -490,8 +494,13 @@ class BasicNewsRecipe(Recipe):
                 return br
 
         '''
+        if 'user_agent' not in kwargs:
+            # More and more news sites are serving JPEG XR images to IE
+            kwargs['user_agent'] = random_user_agent(allow_ie=False)
         br = browser(*args, **kwargs)
         br.addheaders += [('Accept', '*/*')]
+        if self.handle_gzip:
+            br.set_handle_gzip(True)
         return br
 
     def clone_browser(self, br):
@@ -823,9 +832,9 @@ class BasicNewsRecipe(Recipe):
         Called when each HTML page belonging to article is downloaded.
         Intended to be used to get article metadata like author/summary/etc.
         from the parsed HTML (soup).
+
         :param article: A object of class :class:`calibre.web.feeds.Article`.
-        If you change the summary, remember to also change the
-        text_summary
+            If you change the summary, remember to also change the text_summary
         :param soup: Parsed HTML belonging to this article
         :param first: True iff the parsed HTML is the first page of the article.
         '''
